@@ -31,8 +31,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <getopt.h>
-#include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -698,7 +696,7 @@ REAL8 start_freq_from_frame_url(CHAR  *url)
   if (path == NULL)
     path = url;
   else
-    path++; /* skip the ':' -- now on the path */
+    path+=strlen("://localhost"); /* skip the '://localhost' -- now on the path */
 
   frFile =  FrFileINew( path );
   frame = FrameRead (frFile);
@@ -1274,6 +1272,9 @@ REAL8 calculate_lalsim_snr(SimInspiralTable *inj, char *IFOname, REAL8FrequencyS
       exit(1);
     }
 
+    hplus->epoch  = timeHplus->epoch;
+    hcross->epoch = timeHcross->epoch;
+
     XLALSimAddInjectionREAL8TimeSeries(timeHplus, hplus, NULL);
     XLALSimAddInjectionREAL8TimeSeries(timeHcross, hcross, NULL);
     for (j=0; j<(UINT4) timeHplus->data->length; ++j)
