@@ -24,7 +24,7 @@ import subprocess, socket, tempfile
 ##############################################################################
 # import the modules we need to build the pipeline
 from optparse import OptionParser
-import ConfigParser
+from glue.pipeline import DeepCopyableConfigParser as dcConfigParser
 
 from glue import pipeline
 from lalapps import inspiral
@@ -89,7 +89,9 @@ class SBankJob(inspiral.InspiralAnalysisJob):
         self.set_stdout_file('logs/'+tag_base+'-$(macroid)-$(process).out')
         self.set_stderr_file('logs/'+tag_base+'-$(macroid)-$(process).err')
         self.add_condor_cmd('getenv','True')
-        self.add_condor_cmd('Requirements','Memory > 1999')
+        self.add_condor_cmd('request_memory', '1999')
+        if "OMP_NUM_THREADS" in os.environ:
+            self.add_condor_cmd('request_cpus', os.environ["OMP_NUM_THREADS"])
 
 
 class SBankNode(pipeline.CondorDAGNode):
@@ -207,11 +209,13 @@ class BankSimJob(inspiral.InspiralAnalysisJob):
         extension = 'xml'
         sections = ['banksim']
         inspiral.InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
-        self.add_condor_cmd('Requirements','Memory > 1999')
+        self.add_condor_cmd('request_memory', '1999')
         self.tag_base = tag_base
         self.add_condor_cmd('getenv','True')
         self.set_stdout_file('logs/'+tag_base+'-$(macroid)-$(process).out')
         self.set_stderr_file('logs/'+tag_base+'-$(macroid)-$(process).err')
+        if "OMP_NUM_THREADS" in os.environ:
+            self.add_condor_cmd('request_cpus', os.environ["OMP_NUM_THREADS"])
 
 
 class BankSimNode(pipeline.CondorDAGNode):
@@ -223,7 +227,8 @@ class BankSimNode(pipeline.CondorDAGNode):
         self.add_var_opt("user-tag", tag)
         self.add_output_file("%s.h5" % tag)
         for p in p_node:
-            self.add_parent(p)
+            if p is not None:
+                self.add_parent(p)
         dag.add_node(self)
 
 
@@ -257,7 +262,8 @@ class LWAddNode(pipeline.CondorDAGNode):
         self.add_var_opt("output", output)
         self.add_output_file(output)
         for p in p_node:
-            self.add_parent(p)
+            if p is not None:
+                self.add_parent(p)
         dag.add_node(self)
 
 
@@ -273,7 +279,7 @@ class MergeSimsJob(inspiral.InspiralAnalysisJob):
         self.set_stdout_file('logs/'+tag_base+'-$(macroid)-$(process).out')
         self.set_stderr_file('logs/'+tag_base+'-$(macroid)-$(process).err')
         self.add_condor_cmd('getenv','True')
-        self.add_condor_cmd('Requirements','Memory > 1999')
+        self.add_condor_cmd('request_memory', '1999')
 
 
 class MergeSimsNode(pipeline.CondorDAGNode):
@@ -301,7 +307,7 @@ class PlotSimJob(inspiral.InspiralAnalysisJob):
         self.set_stdout_file('logs/'+tag_base+'-$(macroid)-$(process).out')
         self.set_stderr_file('logs/'+tag_base+'-$(macroid)-$(process).err')
         self.add_condor_cmd('getenv','True')
-        self.add_condor_cmd('Requirements','Memory > 1999')
+        self.add_condor_cmd('request_memory', '1999')
 
 
 class PlotSimNode(pipeline.CondorDAGNode):
@@ -324,6 +330,15 @@ takes form given below. Once you have an ini file, create the DAG by
 
 lalapps_cbc_sbank_pipe --config-file INIFILE.ini --user-tag SBANK_PIPE
 
+If already have a bank, but want to patch holes, or extend the
+parameter space it covers, you can provide the option --bank-seed
+BANK_SEED.xml. The bank BANK_SEED.xml can be generated by any means,
+and the resulting DAG will generate a bank with that bank as a subset.
+
+[FIXME: In bank-seed mode, the *banksim* portion is not parallelized
+along the bank seed, so if your bank seed is already most of the final
+bank, your bank sim will spend most of its time on the input bank.]
+
 You can also add --template-bank BANK.xml to run only the sims. To do
 so, you have to remove the "template-weight" option from the [split]
 section.
@@ -384,7 +399,7 @@ convergence-threshold = 50
 ; determine where to put the chirp mass boundaries. When you have a
 ; metric, set it to "equal", otherwise set to "duration". See the sbank_pipe
 ; help for more information.
-nbanks = 250
+nbanks = 100
 template-weight = duration
 
 ;
@@ -465,6 +480,7 @@ def parse_command_line():
     parser.add_option("--config-file", default=None, help="Read options for generating template bank placement pipeline from configuration ini file..")
     parser.add_option("--user-tag", default="SBANK", help="Make your results feel special and give them a unique name.")
     parser.add_option("--template-bank", default=None, help="Skip the template bank generation stage. Use given template bank for bank sim.")
+    parser.add_option("--bank-seed", default=None, help="Use the provided template bank as a start bank. sBank will fill in any holes in this bank.")
     options, filenames = parser.parse_args()
 
     return options, filenames
@@ -478,7 +494,7 @@ except: pass
 dag = bank_DAG(options.user_tag)
 
 # read config file
-cp = ConfigParser.ConfigParser()
+cp = dcConfigParser()
 cp.read(options.config_file)
 
 # initialize sbank job objects
@@ -486,6 +502,11 @@ sbankJob = SBankJob(cp)
 mm = cp.get("sbank", "match-min")
 cp.remove_option("sbank", "match-min")  # don't want it entering via add_ini_opts
 
+# using the bank-seed option in the ini file can only ever lead to
+# problems, so don't let the user do it
+if cp.has_option("sbank", "bank-seed"):
+    raise ValueError("You have indicated a bank seed in the sbank section of the ini file. Please specify instead via the command line option --bank-seed.")
+
 # set up bank generation
 # Two modes:
 #   1. generate coarse, partition mchirp space, generate sub-banks, ligolw_add
@@ -506,14 +527,30 @@ if options.template_bank:
     bank_names = sbankSplitNode.get_output_files()
     bank_nodes = [sbankSplitNode]
 else:
-    # set up sole coarse node to plan out the mini-sbank nodes
-    coarse_sbank_node = SBankNode(sbankJob, dag, "COARSE")
-    coarse_mm = cp.get("coarse-sbank", "match-min")
-    coarse_sbank_node.add_var_opt("match-min", coarse_mm)
-    coarse_thresh = cp.get("coarse-sbank", "convergence-threshold")
-    coarse_sbank_node.add_var_arg("--convergence-threshold %s" % coarse_thresh)
-    xmlCoarse, = coarse_sbank_node.get_output_files()
-    pnode = [coarse_sbank_node]
+    if options.bank_seed:
+        xmlCoarse = options.bank_seed
+        pnode = []
+        bank_names.append(options.bank_seed)
+        bank_nodes.append(None)
+    else:
+        # set up sole coarse node to plan out the mini-sbank nodes
+        coarse_sbank_node = SBankNode(sbankJob, dag, "COARSE")
+        coarse_mm = cp.get("coarse-sbank", "match-min")
+        coarse_sbank_node.add_var_opt("match-min", coarse_mm)
+        coarse_thresh = cp.get("coarse-sbank", "convergence-threshold")
+        coarse_sbank_node.add_var_arg("--convergence-threshold %s" % coarse_thresh)
+
+        if cp.has_option("coarse-sbank", "templates-max"):
+            templates_max = cp.get("coarse-sbank", "templates-max")
+            assert templates_max >= 3*nbanks # you need at least a few templates per bank
+        else:
+            templates_max = 15*nbanks  # to prevent the coarse bank from running forever
+        coarse_sbank_node.add_var_arg("--templates-max %s" % templates_max)
+
+        xmlCoarse, = coarse_sbank_node.get_output_files()
+        pnode = [coarse_sbank_node]
+        bank_names.append(xmlCoarse)
+        bank_nodes.append(None)
 
     # use coarse bank to choose mchirp regions of roughly equal template number
     sbankChooseMchirpBoundariesJob = SBankChooseMchirpBoundariesJob(cp)
@@ -522,7 +559,7 @@ else:
 
     # generate a bank for each mchirp region
     for j in xrange(nbanks):
-        bank_node = SBankNode(sbankJob, dag, "%04d"%j, seed="%d" % (j*nbanks+1), mchirp_boundaries_file=mchirp_boundaries_fname, mchirp_boundaries_index=str(j), p_node=[sbankChooseMchirpBoundariesNode])
+        bank_node = SBankNode(sbankJob, dag, "%04d"%j, seed="%d" % (j*nbanks+1), mchirp_boundaries_file=mchirp_boundaries_fname, mchirp_boundaries_index=str(j), p_node=[sbankChooseMchirpBoundariesNode], bank_seed=xmlCoarse)
         bank_node.add_var_opt("match-min", mm)
         bank_node.set_priority(1)  # want complete bank before sims
         bank_nodes.append(bank_node)
@@ -532,7 +569,7 @@ else:
 # recombine bank fragments under a common name
 if not options.template_bank:
     lwaddJob = LWAddJob(tag_base=options.user_tag + "_lwadd")
-    lwaddNode = LWAddNode(lwaddJob, dag, bank_names, "H1-SBANK_COMBINED-%s.xml"%options.user_tag,bank_nodes)
+    lwaddNode = LWAddNode(lwaddJob, dag, bank_names, "H1-SBANK_COMBINED-%s.xml.gz"%options.user_tag,bank_nodes)
 
 # set up banksim parameters according to sbank parameters (if not provided)
 if not cp.has_option("banksim","flow"):
@@ -542,6 +579,14 @@ if not cp.has_option("banksim","flow"):
 if not cp.has_option("banksim","template-approx"):
     cp.set("banksim","template-approx",cp.get("sbank","approximant"))
 
+# copy over PSD if not specified
+if not cp.has_option("banksim","reference-psd") and not cp.has_option("banksim","noise-model"):
+    if cp.has_option("sbank","reference-psd"):
+        cp.set("banksim","reference-psd",cp.get("sbank","reference-psd"))
+        cp.set("banksim","instrument",cp.get("sbank","instrument"))
+    else:
+        cp.set("banksim","noise-model",cp.get("sbank","noise-model"))
+
 # sim nodes
 banksimJob = BankSimJob(cp)
 
