@@ -20,6 +20,7 @@
 
 /**
  * \file ninja.c
+ * \ingroup lalapps_inspiral
  * \author Badri Krishnan
  * \brief Code for parsing and selecting numerical relativity
  * waves in frame files
@@ -29,7 +30,6 @@
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <getopt.h>
 #include <string.h>
 
 #include <lalapps.h>
@@ -270,7 +270,7 @@ int main(INT4 argc, CHAR *argv[])
     if (path == NULL)
       path = frInCache->list[k].url;
     else
-      path++; /* skip the ':' -- now on the path */
+      path+=strlen("://localhost"); /* skip the ':' -- now on the path */
 
     frFile = FrFileINew(path);
 
