@@ -37,6 +37,7 @@
 #include <lal/LALInferenceTemplate.h>
 #include <lal/LALInferenceProposal.h>
 #include <lal/LALInferenceInit.h>
+#include <lal/LALInferenceCalibrationErrors.h>
 
 #ifdef PARALLEL
 #include <mpi.h>
@@ -144,19 +145,20 @@ void getLogLike(double *Cube, UNUSED int *ndim, UNUSED int *npars, double *lnew,
 
 void dumper(UNUSED int *nSamples, UNUSED int *nlive, UNUSED int *nPar, UNUSED double **physLive,
             UNUSED double **posterior, UNUSED double **paramConstr, UNUSED double *maxLogLike,
-            double *logZ, UNUSED double *logZerr, void *context)
+            double *logZ, double *logZerr, void *context)
 {
     char **info = (char **)context;
     char *root2=&info[0][0];
     char *header=&info[1][0];
     char outfile[BAMBI_STRLEN];
-    FILE *fileout;
+    FILE *fileout = NULL;
 
     /* Write evidence to file for use by post-processing */
+    double logZnoise = (*(REAL8 *)LALInferenceGetVariable(runStateGlobal->algorithmParams, "logZnoise"));
     strcpy(outfile,root2);
     strcat(outfile,"evidence.dat");
     fileout=fopen(outfile,"w");
-    fprintf(fileout,"%g\n",*logZ);
+    fprintf(fileout,"%lf\t%lf\t%lf\n",*logZ,*logZerr,logZnoise);
     fclose(fileout);
 
     /* Write header line to file for use by post-processing */
@@ -273,12 +275,27 @@ void LALInferenceMultiNestAlgorithm(LALInferenceRunState *runState)
     } else
         Ntrain=50;
 
+    INT4 SKY_FRAME=0;
+    if(LALInferenceCheckVariable(runState->currentParams,"SKY_FRAME"))
+      SKY_FRAME=*(INT4 *)LALInferenceGetVariable(runState->currentParams,"SKY_FRAME");
     REAL8 tmin,tmax,tmid;
-    if (LALInferenceCheckVariable(runState->priorArgs,"time"))
+    if (SKY_FRAME==1)
     {
-        LALInferenceGetMinMaxPrior(runState->priorArgs, "time", (void *)&tmin, (void *)&tmax);
-        tmid=(tmax+tmin)/2.0;
-        LALInferenceAddVariable(runState->priorArgs,"trigtime",&tmid,LALINFERENCE_REAL8_t,LALINFERENCE_PARAM_FIXED);
+        if (LALInferenceCheckVariable(runState->priorArgs,"t0"))
+        {
+            LALInferenceGetMinMaxPrior(runState->priorArgs, "t0", (void *)&tmin, (void *)&tmax);
+            tmid=(tmax+tmin)/2.0;
+            LALInferenceAddVariable(runState->priorArgs,"trigtime",&tmid,LALINFERENCE_REAL8_t,LALINFERENCE_PARAM_FIXED);
+        }
+    }
+    else
+    {
+        if (LALInferenceCheckVariable(runState->priorArgs,"time"))
+        {
+            LALInferenceGetMinMaxPrior(runState->priorArgs, "time", (void *)&tmin, (void *)&tmax);
+            tmid=(tmax+tmin)/2.0;
+            LALInferenceAddVariable(runState->priorArgs,"trigtime",&tmid,LALINFERENCE_REAL8_t,LALINFERENCE_PARAM_FIXED);
+        }
     }
 
     runStateGlobal = runState;
@@ -325,7 +342,8 @@ void LALInferenceMultiNestAlgorithm(LALInferenceRunState *runState)
     double mntol = MNTol;
     int ndims = ND;
     int nPar = ndims + 3;
-    if (LALInferenceCheckVariable(runState->currentParams,"fRef")) nPar++;  // add space for fRef
+    if (LALInferenceCheckVariable(runState->currentParams,"f_ref")) nPar++;  // add space for f_ref
+    if (SKY_FRAME==1) nPar += 3;
     int nClsPar = fmin(2,ND);
     int updInt = Ntrain;
     double Ztol = -1.e90;
@@ -374,6 +392,8 @@ void LALInferenceMultiNestAlgorithm(LALInferenceRunState *runState)
     if (netfilestr!=NULL)
         strcpy(networkinputs,netfilestr);
     int rseed = -1;
+    ppt=LALInferenceGetProcParamVal(runState->commandLine,"--randomseed");
+    if(ppt) rseed = atoi(ppt->value) % 30000;
     int fb = verbose;
     int bresume = resval;
     int outfile = 1;
@@ -393,52 +413,11 @@ void LALInferenceMultiNestAlgorithm(LALInferenceRunState *runState)
     strcpy(&info[2][0],"-1");
     void *context = (void *)info;
 
-    /* Read injection XML file for parameters if specified */
-    /* Used to print injection likelihood and prior */
-    /*ppt=LALInferenceGetProcParamVal(runState->commandLine,"--inj");
-    if(ppt){
-      SimInspiralTable *injTable=NULL;
-      SimInspiralTableFromLIGOLw(&injTable,ppt->value,0,0);
-      if(!injTable){
-        fprintf(stderr,"Unable to open injection file %s\n",ppt->value);
-        exit(1);
-      }
-      ppt=LALInferenceGetProcParamVal(runState->commandLine,"--event");
-      if(ppt){
-        int event= atoi(ppt->value);
-        int i=0;
-        while(i<event) {i++; injTable=injTable->next;} // select event
-       LALInferenceVariables tempParams;
-    memset(&tempParams,0,sizeof(tempParams));
-    LALInferenceInjectionToVariables(injTable,&tempParams);
-    LALInferenceVariableItem *node=NULL;
-    item=runState->currentParams->head;
-    for(;item;item=item->next) {
-      node=LALInferenceGetItem(&tempParams,item->name);
-      if(node) {
-        LALInferenceSetVariable(runState->currentParams,node->name,node->value);
-      }
-    }
-    double linj,pinj,lz;
-        char finjname[150];
-        sprintf(finjname,"%sinjlike.txt",root);
-    linj=runState->likelihood(runState->currentParams, runState->data, runState->model);
-        lz = (*(REAL8 *)LALInferenceGetVariable(runState->algorithmParams, "logZnoise"));
-    linj -= lz;
-    pinj = runState->prior(runState,runState->currentParams);
-    FILE *finj=fopen(finjname,"w");
-    fprintf(finj,"Log-likelihood value returned = %g\n",linj);
-    fprintf(finj,"Log-prior value returned = %g\n",pinj);
-    fprintf(finj,"Log-posterior value returned = %g\n",linj+pinj);
-    fprintf(finj,"Noise log-evidence value = %g\n",lz);
-    fclose(finj);
-      }
-    }*/
-
     BAMBIRun(mmodal, ceff, nlive, mntol, efr, ndims, nPar, nClsPar, maxModes, updInt, Ztol, root, rseed, pWrap, fb,
     bresume, outfile, initMPI, logZero, maxiter, LogLike, dumper, bambi, context);
 
-    free(info[1]);free(info[0]);free(info);free(root);free(networkinputs);
+    free(info[2]);free(info[1]);free(info[0]);free(info);
+    free(root);free(networkinputs);
 }
 
 
@@ -518,6 +497,8 @@ Initialisation arguments:\n\
 
         irs->currentLikelihood=LALInferenceNullLogLikelihood(irs->data);
         printf("Null Log Likelihood: %g\n", irs->currentLikelihood);
+        /* Apply calibration errors if desired*/
+        LALInferenceApplyCalibrationErrors(irs,commandLine);
     }
     else
     {
@@ -653,9 +634,6 @@ void initializeMN(LALInferenceRunState *runState)
     if(LALInferenceGetProcParamVal(commandLine,"--skyLocPrior")){
         runState->prior=&LALInferenceInspiralSkyLocPrior;
         runState->CubeToPrior = &LALInferenceInspiralSkyLocCubeToPrior;
-    } else if (LALInferenceGetProcParamVal(commandLine, "--S6Prior")) {
-        runState->prior=&LALInferenceInspiralPriorNormalised;
-        runState->CubeToPrior = &LALInferenceInspiralPriorNormalisedCubeToPrior;
     } else if (LALInferenceGetProcParamVal(commandLine, "--AnalyticPrior")) {
         runState->prior = &LALInferenceAnalyticNullPrior;
         runState->CubeToPrior = &LALInferenceAnalyticCubeToPrior;
@@ -664,8 +642,8 @@ void initializeMN(LALInferenceRunState *runState)
         runState->CubeToPrior = &LALInferenceInspiralCubeToPrior;
         initializeMalmquistPrior(runState);
     } else {
-        runState->prior = &LALInferenceInspiralPriorNormalised;
-        runState->CubeToPrior = &LALInferenceInspiralPriorNormalisedCubeToPrior;
+        runState->prior = &LALInferenceInspiralPrior;
+        runState->CubeToPrior = &LALInferenceInspiralCubeToPrior;
     }
 
     if (LALInferenceGetProcParamVal(commandLine, "--correlatedGaussianLikelihood") ||
@@ -807,10 +785,12 @@ Arguments for each section follow:\n\n";
     else
         state->model = LALInferenceInitCBCModel(state);
 
-    state->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
-    memset(state->currentParams, 0, sizeof(LALInferenceVariables));
-    LALInferenceCopyVariables(state->model->params, state->currentParams);
-    state->templt = state->model->templt;
+    if (state->model) {
+        state->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
+        memset(state->currentParams, 0, sizeof(LALInferenceVariables));
+        LALInferenceCopyVariables(state->model->params, state->currentParams);
+        state->templt = state->model->templt;
+    }
 
     /* Choose the likelihood */
     LALInferenceInitLikelihood(state);
