@@ -39,6 +39,7 @@
 #include <lal/LALInferenceReadData.h>
 #include <lal/LALInferenceInit.h>
 #include <lalapps.h>
+#include <lal/LALInferenceCalibrationErrors.h>
 
 #include <mpi.h>
 
@@ -287,7 +288,6 @@ LALInferenceRunState *initialize(ProcessParamsTable *commandLine)
     fprintf(stdout, " ==== LALInferenceInjectInspiralSignal(): started. ====\n");
     LALInferenceInjectInspiralSignal(irs->data,commandLine);
     fprintf(stdout, " ==== LALInferenceInjectInspiralSignal(): finished. ====\n");
-
     ifoPtr = irs->data;
     while (ifoPtr) {
         nifo++;
@@ -305,6 +305,9 @@ LALInferenceRunState *initialize(ProcessParamsTable *commandLine)
     irs = NULL;
   }
 
+  if(LALInferenceGetProcParamVal(commandLine,"--propVerbose"))
+    irs->proposalStats=XLALCalloc(1,sizeof(LALInferenceVariables));
+
   return(irs);
 }
 
@@ -343,14 +346,8 @@ void initializeMCMC(LALInferenceRunState *runState)
                (--psdFit)                       Run with PSD fitting\n\
                (--psdNblock)                    Number of noise parameters per IFO channel (8)\n\
                (--psdFlatPrior)                 Use flat prior on psd parameters (Gaussian)\n\
-               (--removeLines)                  Do include persistent PSD lines in fourier-domain integration\n\
-               (--KSlines)                      Run with the KS test line removal\n\
-               (--KSlinesWidth)                 Width of the lines removed by the KS test (deltaF)\n\
-               (--chisquaredlines)              Run with the Chi squared test line removal\n\
-               (--chisquaredlinesWidth)         Width of the lines removed by the Chi squared test (deltaF)\n\
-               (--powerlawlines)                Run with the power law line removal\n\
-               (--powerlawlinesWidth)           Width of the lines removed by the power law test (deltaF)\n\
-               (--xcorrbands)                   Run PSD fitting with correlated frequency bands\n\
+               (--glitchFit)                    Run with glitch fitting\n\
+               (--glitchNmax)                   Maximum number of glitch basis functions per IFO (20)\n\
                \n\
                ---------------------------------------------------------------------------------------------------\n\
                --- Proposals  ------------------------------------------------------------------------------------\n\
@@ -410,7 +407,8 @@ void initializeMCMC(LALInferenceRunState *runState)
   if(LALInferenceGetProcParamVal(runState->commandLine,"--help"))
     {
       fprintf(stdout,"%s",help);
-      runState->algorithm=&PTMCMCAlgorithm;
+      //runState->algorithm=&PTMCMCAlgorithm;
+      runState=NULL;
       return;
     }
 
@@ -418,8 +416,6 @@ void initializeMCMC(LALInferenceRunState *runState)
   runState->algorithmParams=XLALCalloc(1,sizeof(LALInferenceVariables));
   runState->priorArgs=XLALCalloc(1,sizeof(LALInferenceVariables));
   runState->proposalArgs=XLALCalloc(1,sizeof(LALInferenceVariables));
-  if(LALInferenceGetProcParamVal(commandLine,"--propVerbose"))
-    runState->proposalStats=XLALCalloc(1,sizeof(LALInferenceVariables));
 
   /* Set up the appropriate functions for the MCMC algorithm */
   runState->algorithm=&PTMCMCAlgorithm;
@@ -472,8 +468,9 @@ void initializeMCMC(LALInferenceRunState *runState)
     malmquist = 1;
     LALInferenceAddVariable(runState->priorArgs, "malmquist", &malmquist, LALINFERENCE_UINT4_t, LALINFERENCE_PARAM_FIXED);
     runState->prior=&LALInferenceInspiralPrior;
-  } else {
-    runState->prior=&LALInferenceInspiralPriorNormalised;
+  }  else {
+     /* By default, use LALInferenceInspiralPrior */
+     runState->prior=&LALInferenceInspiralPrior;
   }
   //runState->prior=PTUniformGaussianPrior;
 
@@ -815,12 +812,21 @@ int main(int argc, char *argv[]){
 
   /* Set up structures for MCMC */
   initializeMCMC(runState);
-  if (runState)
+  if (runState){
     LALInferenceAddVariable(runState->algorithmParams,"MPIrank", &MPIrank, LALINFERENCE_UINT4_t,
                           LALINFERENCE_PARAM_FIXED);
-
-  /* Set up model struct and set currentVariables to match the initialized model params */
-  runState->model = LALInferenceInitCBCModel(runState);
+    /* Apply calibration errors if desired*/
+    LALInferenceApplyCalibrationErrors(runState,runState->commandLine);
+    
+    /* Set up model struct and set currentVariables to match the initialized model params */
+    runState->model = LALInferenceInitCBCModel(runState);
+  }
+  else{
+    //Just to get the help messages
+    LALInferenceApplyCalibrationErrors(NULL,NULL);
+    LALInferenceInitCBCModel(NULL);
+    return 0;
+  }
   runState->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
   memset(runState->currentParams, 0, sizeof(LALInferenceVariables));
   LALInferenceCopyVariables(runState->model->params, runState->currentParams);
