@@ -43,7 +43,7 @@ def compute_weights(data, Nlive):
 
     return log_ev, log_wts
 
-def draw_posterior(data, log_wts):
+def draw_posterior(data, log_wts, verbose=False):
     """Draw points from the given data (of shape (Nsamples, Ndim))
     with associated log(weight) (of shape (Nsamples,)). Draws uniquely so
     there are no repeated samples"""
@@ -53,7 +53,7 @@ def draw_posterior(data, log_wts):
     idx=filter(lambda i: selection[i], range(len(selection)))
     return data[idx,:]
     
-def draw_posterior_many(datas, Nlives,logLcol=-1):
+def draw_posterior_many(datas, Nlives,logLcol=-1, verbose=False):
     """Draw samples from the posteriors represented by the
     (Nruns, Nsamples, Nparams)-shaped array datas, each sampled with
     the corresponding Nlive number of live points. Will draw without repetition,
@@ -61,27 +61,30 @@ def draw_posterior_many(datas, Nlives,logLcol=-1):
 
     # list of log_evidences, log_weights
     log_evs,log_wts=zip(*[compute_weights(data[:,logLcol],Nlive) for data,Nlive in zip(datas, Nlives)])
+    if verbose: print 'Computed log_evidences: %s'%(str(log_evs))
 
     log_total_evidence=reduce(logaddexp, log_evs)
     log_max_evidence=max(log_evs)
     #print 'evidences: %s'%(str(log_evs))
     fracs=[exp(log_ev-log_max_evidence) for log_ev in log_evs]
-    #print 'Relative weights of input files: %s'%(str(fracs))
+    if verbose: print 'Relative weights of input files: %s'%(str(fracs))
     Ns=[fracs[i]/len(datas[i]) for i in range(len(fracs))]
     Ntot=max(Ns)
     fracs=[n/Ntot for n in Ns]
-    #print 'Relative weights of input files taking into account their length: %s'%(str(fracs))
+    if verbose: print 'Relative weights of input files taking into account their length: %s'%(str(fracs))
 
     bigpos=[]
     posts=[draw_posterior(data,logwt) for (data,logwt,logZ) in zip(datas,log_wts,log_evs)]
-    #print 'Expected number of samples from each input file %s'%(str([int(f*len(p)) for f,p in zip(fracs,posts)]))
+    if verbose: print 'Number of input samples: %s'%(str([len(x) for x in log_wts]))
+    if verbose: print 'Expected number of samples from each input file %s'%(str([int(f*len(p)) for f,p in zip(fracs,posts)]))
     for post,frac in zip(posts,fracs):
     	for samp in post:
 	    if(uniform()<frac):
 	    	bigpos.append(samp)
+    if verbose: print 'Total number of samples produced: %i'%(len(bigpos))
     return bigpos
     
-def draw_N_posterior(data,log_wts, N):
+def draw_N_posterior(data,log_wts, N, verbose=False):
     """
     Draw N samples from the input data, weighted by log_wt.
     For large N there may be repeated samples
@@ -97,7 +100,7 @@ def draw_N_posterior(data,log_wts, N):
 
     return data[idxs-1, :]
 
-def draw_N_posterior_many(datas, Nlives, Npost, logLcol=-1):
+def draw_N_posterior_many(datas, Nlives, Npost, logLcol=-1, verbose=False):
     """
     Draw Npost samples from the posteriors represented by the
     (Nruns, Nsamples, Nparams)-shaped array datas, each sampled with
