@@ -24,12 +24,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
-
-#define _GNU_SOURCE
-#include "getopt.h"
 
 #include <lal/LALStdlib.h>
+#include <lal/LALgetopt.h>
 #include <lal/LALConstants.h>
 #include <lal/Date.h>
 #include "getdate.h"
@@ -306,9 +303,9 @@ static void output_jd( int gps_sec )
   struct tm utc;
   double jd;
   utc = *XLALGPSToUTC( &utc, gps_sec );
-  jd = XLALJulianDay( &utc );
+  jd = XLALJulianDayUTC( &utc );
   if ( verbose )
-    printf( "Julian Day = " );
+    printf( "Julian Day (UTC)  = " );
   printf( "%.6f\n", jd );
   return;
 }
@@ -319,10 +316,10 @@ static void output_mjd( int gps_sec )
   double jd;
   double mjd;
   utc = *XLALGPSToUTC( &utc, gps_sec );
-  jd = XLALJulianDay( &utc );
+  jd = XLALJulianDayUTC( &utc );
   mjd = jd - XLAL_MJD_REF;
   if ( verbose )
-    printf( "Modified Julian Day = " );
+    printf( "Modified Julian Day (UTC) = " );
   printf( "%.6f\n", mjd );
   return;
 }
@@ -631,7 +628,7 @@ void usage( const char *program, int exitcode )
                 output date string in ISO 8601 format\n\
         \n\
         -j, --jd, --julian-day\n\
-                output Julian day\n\
+                output Julian day (in UTC time system)\n\
         \n\
         -l, --leap-seconds\n\
                 output number of leap seconds (TAI-UTC)\n\
@@ -640,7 +637,7 @@ void usage( const char *program, int exitcode )
                 date strings formatted for local time (current TZ setting)\
         \n\
         -m, --mjd, --modified-julian-day\n\
-                output modified Julian day\n\
+                output modified Julian day (in UTC time system)\n\
         \n\
         -R, --rfc-2822\n\
                 output RFC-2822 compliant date string\n\
@@ -685,7 +682,7 @@ void usage( const char *program, int exitcode )
         \n\
                 %s --sidereal-time --site=LHO 3 hours ago\n\
         \n\
-        Get the Julian day of Y2K (UTC is default unless --local is used):\n\
+        Get the Julian day(UTC) of Y2K (UTC is default unless --local is used):\n\
         \n\
                 %s --julian-day Jan 1, 2000\n\
         \n\
@@ -705,7 +702,7 @@ void usage( const char *program, int exitcode )
 
 char * parse_options( char *buf, int buflen, int argc, char **argv )
 {
-  struct option long_options[] =
+  struct LALoption long_options[] =
   {
     { "date",           no_argument,            0,      'd'     },
     { "format",         required_argument,      0,      'f'     },
@@ -739,7 +736,7 @@ char * parse_options( char *buf, int buflen, int argc, char **argv )
     int option_index = 0;
     int c;
 
-    c = getopt_long_only( argc, argv, args, long_options, &option_index );
+    c = LALgetopt_long_only( argc, argv, args, long_options, &option_index );
     if ( c == -1 ) /* end of options */
       break;
 
@@ -750,7 +747,7 @@ char * parse_options( char *buf, int buflen, int argc, char **argv )
         if ( ! long_options[option_index].flag )
         {
           fprintf( stderr, "error parsing option %s with argument %s\n",
-              long_options[option_index].name, optarg );
+              long_options[option_index].name, LALoptarg );
           usage( program, 1 );
         }
         break;
@@ -760,7 +757,7 @@ char * parse_options( char *buf, int buflen, int argc, char **argv )
         break;
 
       case 'f': /* format */
-        output_date_format = optarg;
+        output_date_format = LALoptarg;
         break;
 
       case 'G': /* gps-epoch */
@@ -797,15 +794,15 @@ char * parse_options( char *buf, int buflen, int argc, char **argv )
 
       case 's': /* sidereal-time */
         output_type = OUTPUT_GMST;
-        if ( optarg )
+        if ( LALoptarg )
         {
-          if ( ! strcmp( optarg, "rad" ) || ! strcmp( optarg, "RAD" ) )
+          if ( ! strcmp( LALoptarg, "rad" ) || ! strcmp( LALoptarg, "RAD" ) )
             sidereal_format = SIDEREAL_RAD;
-          else if ( ! strcmp( optarg, "hms" ) || ! strcmp( optarg, "HMS" ) )
+          else if ( ! strcmp( LALoptarg, "hms" ) || ! strcmp( LALoptarg, "HMS" ) )
             sidereal_format = SIDEREAL_HMS;
           else
           {
-            fprintf( stderr, "unrecognized sidereal time format %s\n", optarg );
+            fprintf( stderr, "unrecognized sidereal time format %s\n", LALoptarg );
             fprintf( stderr, "expect \"HMS\" (hours:minutes:seconds)" );
             fprintf( stderr, "or \"RAD\" (radians)\n" );
             exit( 1 );
@@ -839,17 +836,17 @@ char * parse_options( char *buf, int buflen, int argc, char **argv )
         break;
 
       case 'z': /* zone */
-        tz = optarg;
+        tz = LALoptarg;
         break;
 
       case 'Z': /* site */
-        if ( strcmp( optarg, "LHO" ) == 0 || strcmp( optarg, "lho" ) == 0 )
+        if ( strcmp( LALoptarg, "LHO" ) == 0 || strcmp( LALoptarg, "lho" ) == 0 )
           site = SITE_LHO;
-        else if ( strcmp( optarg, "LLO" ) == 0 || strcmp( optarg, "llo" ) == 0 )
+        else if ( strcmp( LALoptarg, "LLO" ) == 0 || strcmp( LALoptarg, "llo" ) == 0 )
           site = SITE_LLO;
         else
         {
-          fprintf( stderr, "unrecognized detector site %s\n", optarg );
+          fprintf( stderr, "unrecognized detector site %s\n", LALoptarg );
           fprintf( stderr, "expect either \"LHO\" or \"LLO\"\n" );
           exit( 1 );
         }
@@ -863,18 +860,18 @@ char * parse_options( char *buf, int buflen, int argc, char **argv )
     }
   }
 
-  if ( optind == argc && fp )
+  if ( LALoptind == argc && fp )
   {
       char UNUSED *c;
       c = fgets( buf, buflen, fp );
   }
   else
   {
-    for ( ; optind < argc; ++optind )
+    for ( ; LALoptind < argc; ++LALoptind )
     {
       int len;
       len = strlen( buf );
-      strncat( buf + len, argv[optind], buflen - len );
+      strncat( buf + len, argv[LALoptind], buflen - len );
       len = strlen( buf );
       if ( len == buflen )
       {
