@@ -17,9 +17,12 @@
 *  MA  02111-1307  USA
 */
 
+#include <config.h>
 
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include "GCTtoplist.h"
 #include "HeapToplist.h"
 #include <lal/StringInput.h> /* for LAL_REAL8_FORMAT etc. */
@@ -32,6 +35,7 @@
 #if defined(USE_BOINC) || defined(EAH_BOINC)
 #include "hs_boinc_options.h"
 #ifdef _WIN32
+#include "win_lib.h" // for eah_rename()
 /* On MS Windows boinc_rename() is not as atomic as rename()
    on POSIX systems. We therefore use our own implementation
    eah_rename (in win_lib.h) */
@@ -49,7 +53,9 @@
 
 /* errno */
 extern int errno;
+#ifndef _doserrno
 extern int _doserrno;
+#endif
 
 /* snprintf */
 #define snprintf _snprintf
@@ -89,13 +95,13 @@ static FILE*debugfp = NULL;
 extern char *global_column_headings_stringp;
 
 /* local prototypes */
-static void reduce_gctFStat_toplist_precision(toplist_t *l);
-static int _atomic_write_gctFStat_toplist_to_file(toplist_t *l, const char *filename, UINT4*checksum, int write_done);
-static int print_gctFStatline_to_str(GCTtopOutputEntry fline, char* buf, int buflen);
-static int write_gctFStat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, UINT4*checksum);
+static void reduce_gctFstat_toplist_precision(toplist_t *l);
+static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *filename, UINT4*checksum, int write_done);
+static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buflen);
+static int write_gctFstat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, UINT4*checksum);
 
 /* ordering function for sorting the list */
-static int gctFStat_result_order(const void *a, const void *b) {
+static int gctFstat_result_order(const void *a, const void *b) {
 #ifdef DEBUG_SORTING
   if(debugfp)
     fprintf(debugfp,"%20lf  %20lf\n%20lf  %20lf\n%20lf  %20lf\n%20lf  %20lf\n\n",
@@ -125,7 +131,7 @@ static int gctFStat_result_order(const void *a, const void *b) {
 }
 
 /* ordering function defining the toplist: SORT BY avTwoF */
-static int gctFStat_smaller(const void*a, const void*b) {
+static int gctFstat_smaller(const void*a, const void*b) {
 #ifdef DEBUG_SORTING
   if(debugfp)
     fprintf(debugfp,"%20lf  %20lf\n%20u  %20u\n\n",
@@ -141,7 +147,7 @@ static int gctFStat_smaller(const void*a, const void*b) {
   else if (((const GCTtopOutputEntry*)a)->nc > ((const GCTtopOutputEntry*)b)->nc)
     return -1;
   else
-    return(gctFStat_result_order(a,b));
+    return(gctFstat_result_order(a,b));
 }
 
 
@@ -162,7 +168,7 @@ static int gctNC_smaller(const void*a, const void*b) {
   else if (((const GCTtopOutputEntry*)a)->avTwoF > ((const GCTtopOutputEntry*)b)->avTwoF)
     return -1;
   else
-    return(gctFStat_result_order(a,b));
+    return(gctFstat_result_order(a,b));
 }
 
 
@@ -183,21 +189,21 @@ static int gctBSGL_smaller(const void*a, const void*b) {
   else if (((const GCTtopOutputEntry*)a)->avTwoF > ((const GCTtopOutputEntry*)b)->avTwoF)
     return -1;
   else
-    return(gctFStat_result_order(a,b));
+    return(gctFstat_result_order(a,b));
 }
 
 
 /* functions for qsort based on the above ordering functions */
-static int gctFStat_final_qsort(const void*a, const void*b) {
+static int gctFstat_final_qsort(const void*a, const void*b) {
   void const* const* pa = (void const* const*)a;
   void const* const* pb = (void const* const*)b;
-  return(gctFStat_result_order(*pa,*pb));
+  return(gctFstat_result_order(*pa,*pb));
 }
 
 
 /* creates a toplist with length elements,
    returns -1 on error (usually out of memory), else 0 */
-int create_gctFStat_toplist(toplist_t**tl, UINT8 length, UINT4 whatToSortBy) {
+int create_gctFstat_toplist(toplist_t**tl, UINT8 length, UINT4 whatToSortBy) {
 #ifdef DEBUG_SORTING
   if(!debugfp)
     debugfp=fopen("debug_sort","w");
@@ -210,16 +216,16 @@ int create_gctFStat_toplist(toplist_t**tl, UINT8 length, UINT4 whatToSortBy) {
     return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctBSGL_smaller) );
   }
   else {
-    return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctFStat_smaller) );
+    return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctFstat_smaller) );
   }
 
 }
 
 /* frees the space occupied by the toplist
    NOTE: toplist must not contain any allocated structs */
-void free_gctFStat_toplist(toplist_t**l) {
+void free_gctFstat_toplist(toplist_t**l) {
   free_toplist(l);
-} /* free_gctFStat_toplist() */
+} /* free_gctFstat_toplist() */
 
 
 /* Inserts an element in to the toplist either if there is space left
@@ -227,7 +233,7 @@ void free_gctFStat_toplist(toplist_t**l) {
    In the latter case, remove the smallest element from the toplist and
    look for the now smallest one.
    Returns 1 if the element was actually inserted, 0 if not. */
-int insert_into_gctFStat_toplist(toplist_t*tl, GCTtopOutputEntry elem) {
+int insert_into_gctFstat_toplist(toplist_t*tl, GCTtopOutputEntry elem) {
   if ( !tl )
     return 0;
   else
@@ -235,13 +241,13 @@ int insert_into_gctFStat_toplist(toplist_t*tl, GCTtopOutputEntry elem) {
 }
 
 /* (q)sort the toplist according to the sorting function. */
-void sort_gctFStat_toplist(toplist_t*l) {
-  qsort(l->heap,l->elems,sizeof(char*),gctFStat_final_qsort);
+void sort_gctFstat_toplist(toplist_t*l) {
+  qsort(l->heap,l->elems,sizeof(char*),gctFstat_final_qsort);
 }
 
 /* Prints a Toplist line to a string buffer.
    Separate function to assure consistency of output and reduced precision for sorting */
-static int print_gctFStatline_to_str(GCTtopOutputEntry fline, char* buf, int buflen) {
+static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buflen) {
   const char *fn = __func__;
 
   /* add extra output field for line-robust statistic BSGL */
@@ -255,7 +261,7 @@ static int print_gctFStatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
           snprintf ( buf0, sizeof(buf0), " %.6f", fline.avTwoFX[X] );
           UINT4 len1 = strlen ( BSGLstr ) + strlen ( buf0 ) + 1;
           if ( len1 > sizeof ( BSGLstr ) ) {
-            XLALPrintError ("%s: assembled output string too long! (%d > %d)\n", fn, len1, sizeof(BSGLstr ));
+            XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len1, sizeof(BSGLstr ));
             break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
           }
           strcat ( BSGLstr, buf0 );
@@ -278,7 +284,7 @@ static int print_gctFStatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
           snprintf ( buf0, sizeof(buf0), " %.6f", fline.avTwoFXrecalc[X] );
           UINT4 len1 = strlen ( recalcStr ) + strlen ( buf0 ) + 1;
           if ( len1 > sizeof ( recalcStr ) ) {
-            XLALPrintError ("%s: assembled output string too long! (%d > %d)\n", fn, len1, sizeof(recalcStr ));
+            XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len1, sizeof(recalcStr ));
             break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
           }
           strcat ( recalcStr, buf0 );
@@ -292,7 +298,7 @@ static int print_gctFStatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
             snprintf ( buf0, sizeof(buf0), " %.6f", fline.twoFXloudestSeg[X] );
             UINT4 len1 = strlen ( recalcStr ) + strlen ( buf0 ) + 1;
             if ( len1 > sizeof ( recalcStr ) ) {
-              XLALPrintError ("%s: assembled output string too long! (%d > %d)\n", fn, len1, sizeof(recalcStr ));
+              XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len1, sizeof(recalcStr ));
               break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
             }
             strcat ( recalcStr, buf0 );
@@ -344,18 +350,18 @@ static int print_gctFStatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
 }
   return len;
 
-} /* print_gctFStatline_to_str() */
+} /* print_gctFstatline_to_str() */
 
 
 
 /* writes an GCTtopOutputEntry line to an open filepointer.
    Returns the number of chars written, -1 if in error
    Updates checksum if given */
-static int write_gctFStat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, UINT4*checksum) {
+static int write_gctFstat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, UINT4*checksum) {
   char linebuf[256];
   UINT4 i;
 
-  UINT4 length = print_gctFStatline_to_str(fline, linebuf, sizeof(linebuf)-1);
+  UINT4 length = print_gctFstatline_to_str(fline, linebuf, sizeof(linebuf)-1);
 
   if(length>sizeof(linebuf)-1) {
     return -1;
@@ -365,7 +371,7 @@ static int write_gctFStat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, U
     for(i=0;i<length;i++)
       *checksum += linebuf[i];
 
-  linebuf[sizeof(linebuf)-1] = '\0';
+  XLAL_LAST_ELEM(linebuf) = '\0';
 
   return(fprintf(fp,"%s",linebuf));
 }
@@ -374,9 +380,9 @@ static int write_gctFStat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, U
 
 /* Reduces the precision of all elements in the toplist which influence the sorting order.
    To be called before sorting and finally writing out the list */
-static void reduce_gctFStatline_precision(void*line) {
+static void reduce_gctFstatline_precision(void*line) {
   char linebuf[256];
-  print_gctFStatline_to_str((*(GCTtopOutputEntry*)line), linebuf, sizeof(linebuf));
+  print_gctFstatline_to_str((*(GCTtopOutputEntry*)line), linebuf, sizeof(linebuf));
   sscanf(linebuf,
          "%" LAL_REAL8_FORMAT
          " %" LAL_REAL8_FORMAT
@@ -389,21 +395,21 @@ static void reduce_gctFStatline_precision(void*line) {
          &((*(GCTtopOutputEntry*)line).F1dot));
 }
 
-static void reduce_gctFStat_toplist_precision(toplist_t *l) {
-  go_through_toplist(l,reduce_gctFStatline_precision);
+static void reduce_gctFstat_toplist_precision(toplist_t *l) {
+  go_through_toplist(l,reduce_gctFstatline_precision);
 }
 
 
 /* Writes the toplist to an (already open) filepointer
    Returns the number of written charactes
    Returns something <0 on error */
-int write_gctFStat_toplist_to_fp(toplist_t*tl, FILE*fp, UINT4*checksum) {
+int write_gctFstat_toplist_to_fp(toplist_t*tl, FILE*fp, UINT4*checksum) {
   UINT8 c=0,i;
   INT8 r;
   if(checksum)
     *checksum = 0;
   for(i=0;i<tl->elems;i++)
-    if ((r = write_gctFStat_toplist_item_to_fp(*((GCTtopOutputEntry*)(void*)(tl->heap[i])), fp, checksum)) < 0) {
+    if ((r = write_gctFstat_toplist_item_to_fp(*((GCTtopOutputEntry*)(void*)(tl->heap[i])), fp, checksum)) < 0) {
       LogPrintf (LOG_CRITICAL, "Failed to write toplistitem to output fp: %d: %s\n",
 		 errno,strerror(errno));
 #ifdef _MSC_VER
@@ -416,10 +422,10 @@ int write_gctFStat_toplist_to_fp(toplist_t*tl, FILE*fp, UINT4*checksum) {
 }
 
 
-/* function that does the actual work of atomic_write_gctFStat_toplist_to_file(),
-   appending a %DONE marker if specified (not when called from atomic_write_gctFStat_toplist_to_file().
+/* function that does the actual work of atomic_write_gctFstat_toplist_to_file(),
+   appending a %DONE marker if specified (not when called from atomic_write_gctFstat_toplist_to_file().
    NOTE that the checksum will be a little wrong when %DOME is appended, as this line is not counted */
-static int _atomic_write_gctFStat_toplist_to_file(toplist_t *l, const char *filename, UINT4*checksum, int write_done) {
+static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *filename, UINT4*checksum, int write_done) {
   char* tempname;
   INT4 length=0;
   FILE * fpnew;
@@ -438,7 +444,7 @@ static int _atomic_write_gctFStat_toplist_to_file(toplist_t *l, const char *file
 
   fpnew=LALFopen(tempname, "wb");
   if(!fpnew) {
-    LogPrintf (LOG_CRITICAL, "Failed to open temp gctFStat file \"%s\" for writing: %d: %s\n",
+    LogPrintf (LOG_CRITICAL, "Failed to open temp gctFstat file \"%s\" for writing: %d: %s\n",
 	       tempname,errno,strerror(errno));
 #ifdef _MSC_VER
     LogPrintf (LOG_CRITICAL, "Windows system call returned: %d\n", _doserrno);
@@ -489,7 +495,7 @@ static int _atomic_write_gctFStat_toplist_to_file(toplist_t *l, const char *file
        NOTE this does not necessarily correspond to the actual output-file row sorting, which by default is done by frequency */
     if (length >= 0) {
       const CHAR *sortstat = NULL;
-      if ( l->smaller == gctFStat_smaller )
+      if ( l->smaller == gctFstat_smaller )
         sortstat = "<2F>";
       else if ( l->smaller == gctNC_smaller )
         sortstat = "nc";
@@ -521,7 +527,7 @@ static int _atomic_write_gctFStat_toplist_to_file(toplist_t *l, const char *file
 
   /* write the actual toplist */
   if (length >= 0) {
-    ret = write_gctFStat_toplist_to_fp(l,fpnew,checksum);
+    ret = write_gctFstat_toplist_to_fp(l,fpnew,checksum);
       if (ret < 0)
 	length = ret;
       else
@@ -540,7 +546,7 @@ static int _atomic_write_gctFStat_toplist_to_file(toplist_t *l, const char *file
   fclose(fpnew);
 
   if (length < 0) {
-    LogPrintf (LOG_CRITICAL, "Failed to write temp gctFStat file \"%s\": %d: %s\n",
+    LogPrintf (LOG_CRITICAL, "Failed to write temp gctFstat file \"%s\": %d: %s\n",
 	       tempname,errno,strerror(errno));
 #ifdef _MSC_VER
     LogPrintf (LOG_CRITICAL, "Windows system call returned: %d\n", _doserrno);
@@ -550,7 +556,7 @@ static int _atomic_write_gctFStat_toplist_to_file(toplist_t *l, const char *file
   }
 
   if(rename(tempname, filename)) {
-    LogPrintf (LOG_CRITICAL, "Failed to rename gctFStat file to \"%s\": %d: %s\n",
+    LogPrintf (LOG_CRITICAL, "Failed to rename gctFstat file to \"%s\": %d: %s\n",
 	       filename,errno,strerror(errno));
 #ifdef _MSC_VER
     LogPrintf (LOG_CRITICAL, "Windows system call returned: %d\n", _doserrno);
@@ -637,7 +643,7 @@ int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4
   len = fwrite(tl->data, tl->size, tl->elems, fp);
   if(len != tl->elems) {
     LOGIOERROR("Couldn't write data to", tmpfilename);
-    LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %d\n", len, tl->elems);
+    LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %zu\n", len, tl->elems);
     if(fclose(fp))
       LOGIOERROR("In addition: couldn't close", tmpfilename);
     LALFree(tmpfilename);
@@ -676,7 +682,7 @@ int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4
     len = fwrite(t2->data, t2->size, t2->elems, fp);
     if(len != t2->elems) {
       LOGIOERROR("Couldn't write data to", tmpfilename);
-      LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %d\n", len, t2->elems);
+      LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %zu\n", len, t2->elems);
       if(fclose(fp))
 	LOGIOERROR("In addition: couldn't close", tmpfilename);
       LALFree(tmpfilename);
@@ -810,7 +816,7 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
   /* sanity check */
   if (tl->elems > tl->length) {
     LogPrintf(LOG_CRITICAL,
-	      "Number of elements read larger than length of toplist: %d, > %d\n",
+	      "Number of elements read larger than length of toplist: %zu > %zu\n",
 	      tl->elems, tl->length);
     if(fclose(fp))
       LOGIOERROR("In addition: couldn't close", filename);
@@ -821,7 +827,7 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
   len = fread(tl->data, tl->size, tl->elems, fp);
   if(len != tl->elems) {
     LOGIOERROR("Couldn't read data from", filename);
-    LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %d\n", len, tl->elems);
+    LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %zu\n", len, tl->elems);
     if(fclose(fp))
       LOGIOERROR("In addition: couldn't close", filename);
     clear_toplist(tl);
@@ -858,7 +864,7 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
     /* sanity check */
     if (t2->elems > t2->length) {
       LogPrintf(LOG_CRITICAL,
-		"Number of elements read larger than length of toplist: %d, > %d\n",
+		"Number of elements read larger than length of toplist: %zu > %zu\n",
 		t2->elems, t2->length);
       if(fclose(fp))
 	LOGIOERROR("In addition: couldn't close", filename);
@@ -869,7 +875,7 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
     len = fread(t2->data, t2->size, t2->elems, fp);
     if(len != t2->elems) {
       LOGIOERROR("Couldn't read data from", filename);
-      LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %d\n", len, t2->elems);
+      LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %zu\n", len, t2->elems);
       if(fclose(fp))
 	LOGIOERROR("In addition: couldn't close", filename);
       clear_toplist(tl);
@@ -987,10 +993,10 @@ static void dump_heap_order(const toplist_t*tl, const char*name) {
   }
 }
 
-static void sort_gctFStat_toplist_debug(toplist_t*l) {
+static void sort_gctFstat_toplist_debug(toplist_t*l) {
   if(!debugfp)
     debugfp=fopen("debug_sort","w");
-  sort_gctFStat_toplist(l);
+  sort_gctFstat_toplist(l);
   if(debugfp) {
     fclose(debugfp);
     debugfp=NULL;
@@ -1002,13 +1008,13 @@ int write_hfs_oputput(const char*filename, toplist_t*tl) {
   /* reduce the precision of the calculated values before doing the sort to
      the precision we will write the result with. This should ensure a sorting
      order that looks right to the validator, too */
-  reduce_gctFStat_toplist_precision(tl);
+  reduce_gctFstat_toplist_precision(tl);
 #ifdef DEBUG_SORTING
   dump_heap_order(tl,"heap_before.dump");
-  sort_gctFStat_toplist_debug(tl);
+  sort_gctFstat_toplist_debug(tl);
   dump_heap_order(tl,"heap_after.dump");
 #else
-  sort_gctFStat_toplist(tl);
+  sort_gctFstat_toplist(tl);
 #endif
-  return(_atomic_write_gctFStat_toplist_to_file(tl, filename, NULL, 1));
+  return(_atomic_write_gctFstat_toplist_to_file(tl, filename, NULL, 1));
 }
