@@ -22,7 +22,7 @@
 
 /**
  * \file
- * \ingroup pulsarApps
+ * \ingroup lalapps_pulsar_Injections
  * \author R. Prix, M.A. Papa, X. Siemens, B. Allen, C. Messenger
  */
 
@@ -105,7 +105,7 @@ typedef struct
 
   /* specify start + duration */
   LALStringVector *timestampsFiles;        /**< Names of numDet timestamps files */
-  INT4 startTime;		/**< Start-time of requested signal in detector-frame (GPS seconds) */
+  LIGOTimeGPS startTime;	/**< Start-time of requested signal in detector-frame (GPS seconds) */
   INT4 duration;		/**< Duration of requested signal in seconds */
 
   /* time-series sampling + heterodyning frequencies */
@@ -131,7 +131,7 @@ typedef struct
   CHAR *ephemSun;		/**< Sun ephemeris file to use */
 
   /* pulsar parameters */
-  LALStringVector *injectionSources;	///< either a file-specification ("@file-pattern") or a config-string defining the sources to inject
+  LALStringVector *injectionSources;	///< Source parameters to inject: comma-separated list of file-patterns and/or direct config-strings ('{...}')
 
   BOOLEAN version;		/**< output version information */
 
@@ -218,7 +218,7 @@ main(int argc, char *argv[])
       CHAR *logstr;
       XLAL_CHECK ( (logstr = XLALUserVarGetLog ( UVAR_LOGFMT_CMDLINE )) != NULL, XLAL_EFUNC );
       char *comment = XLALCalloc ( 1, len = strlen ( logstr ) + strlen(GV.VCSInfoString) + 512 );
-      XLAL_CHECK ( comment != NULL, XLAL_ENOMEM, "XLALCalloc(1,%d) failed.\n", len );
+      XLAL_CHECK ( comment != NULL, XLAL_ENOMEM, "XLALCalloc(1,%lu) failed.\n", len );
       sprintf ( comment, "Generated by:\n%s\n%s\n", logstr, GV.VCSInfoString );
 
       for ( UINT4 X=0; X < mSFTs->length; X ++ )
@@ -243,7 +243,7 @@ main(int argc, char *argv[])
     {
       FILE *fp;
       CHAR *fname = XLALCalloc (1, len = strlen(uvar.TDDfile) + 10 );
-      XLAL_CHECK ( fname != NULL, XLAL_ENOMEM, "XLALCalloc(1,%d) failed\n", len );
+      XLAL_CHECK ( fname != NULL, XLAL_ENOMEM, "XLALCalloc(1,%lu) failed\n", len );
 
       for ( UINT4 X=0; X < mTseries->length; X ++ )
         {
@@ -281,7 +281,7 @@ main(int argc, char *argv[])
           XLAL_CHECK ( (fname = LALCalloc (1, len )) != NULL, XLAL_ENOMEM );
           size_t written = snprintf ( fname, len, "%s/%c-%c%c_%s-%d-%d.gwf",
                                       uvar.TDDframedir, IFO[0], IFO[0], IFO[1], uvar.outLabel, startTimeGPS.gpsSeconds, (int)duration );
-          XLAL_CHECK ( written < len, XLAL_ESIZE, "Frame-filename exceeds expected maximal length (%d): '%s'\n", len, fname );
+          XLAL_CHECK ( written < len, XLAL_ESIZE, "Frame-filename exceeds expected maximal length (%lu): '%s'\n", len, fname );
 
           /* define the output frame */
           LALFrameH *outFrame;
@@ -391,11 +391,13 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
       if ( have_startTime && have_duration )	 // use optional (startTime+duration) as constraints,
         {
           LIGOTimeGPS minStartTime, maxStartTime;
-          XLALGPSSetREAL8 ( &minStartTime, uvar->startTime );
-          XLALGPSSetREAL8 ( &maxStartTime, uvar->startTime + uvar->duration );
+          minStartTime = uvar->startTime;
+          maxStartTime = uvar->startTime;
+          XLALGPSAdd ( &maxStartTime, uvar->duration );
           constraints.minStartTime = &minStartTime;
-          constraints.maxStartTime   = &maxStartTime;
-          XLALPrintWarning ( "Only noise-SFTs between GPS [%d, %d] will be used!\n", uvar->startTime, uvar->startTime + uvar->duration );
+          constraints.maxStartTime = &maxStartTime;
+          char bufGPS1[32], bufGPS2[32];
+          XLALPrintWarning ( "Only noise-SFTs between GPS [%s, %s] will be used!\n", XLALGPSToStr(bufGPS1, &minStartTime), XLALGPSToStr(bufGPS2, &maxStartTime) );
         } /* if start+duration given */
       XLAL_CHECK ( (cfg->noiseCatalog = XLALSFTdataFind ( uvar->noiseSFTs, &constraints )) != NULL, XLAL_EFUNC );
       XLAL_CHECK (  cfg->noiseCatalog->length > 0, XLAL_EINVAL, "No noise-SFTs matching (start+duration, timestamps) were found!\n" );
@@ -411,7 +413,7 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
     {
       XLAL_CHECK ( (cfg->multiTimestamps = XLALReadMultiTimestampsFiles ( uvar->timestampsFiles )) != NULL, XLAL_EFUNC );
 
-      XLAL_CHECK ( (cfg->multiTimestamps->length > 0) && (cfg->multiTimestamps->data != NULL), XLAL_EINVAL, "Got empty timestamps-list from '%s'\n", uvar->timestampsFiles );
+      XLAL_CHECK ( (cfg->multiTimestamps->length > 0) && (cfg->multiTimestamps->data != NULL), XLAL_EINVAL, "Got empty timestamps-list from XLALReadMultiTimestampsFiles()\n" );
 
       XLAL_CHECK ( have_IFOs, XLAL_EINVAL, "Need --IFOs with --timestampsFiles\n" );	// paranoia check
 
@@ -421,9 +423,7 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
     } // endif have_timestampsFiles
   else if ( have_startTime && have_duration )
     {
-      LIGOTimeGPS tStart;
-      XLALGPSSetREAL8 ( &tStart, uvar->startTime );
-      XLAL_CHECK ( ( cfg->multiTimestamps = XLALMakeMultiTimestamps ( tStart, uvar->duration, uvar->Tsft, uvar->SFToverlap, cfg->multiIFO.length )) != NULL, XLAL_EFUNC );
+      XLAL_CHECK ( ( cfg->multiTimestamps = XLALMakeMultiTimestamps ( uvar->startTime, uvar->duration, uvar->Tsft, uvar->SFToverlap, cfg->multiIFO.length )) != NULL, XLAL_EFUNC );
     } // endif have_startTime
   else {
     XLAL_ERROR (XLAL_EFAILED, "Something went wrong with my internal logic ..\n");
@@ -494,7 +494,7 @@ XLALInitUserVars ( UserVariables_t *uvar, int argc, char *argv[] )
   XLALregSTRINGUserStruct( ephemSun, 	 	0,  UVAR_OPTIONAL, "Sun ephemeris file to use");
 
   /* start + duration of timeseries */
-  XLALregINTUserStruct (  startTime,            'G', UVAR_OPTIONAL, "Start-time of requested signal in detector-frame (GPS seconds)");
+  XLALregEPOCHUserStruct (startTime,            'G', UVAR_OPTIONAL, "Start-time of requested signal in detector-frame (format 'xx.yy[GPS|MJD]')");
   XLALregINTUserStruct (  duration,              0,  UVAR_OPTIONAL, "Duration of requested signal in seconds");
   XLALregLISTUserStruct ( timestampsFiles,       0,  UVAR_OPTIONAL, "ALTERNATIVE: File to read timestamps from (file-format: lines with <seconds> <nanoseconds>)");
 
@@ -509,7 +509,7 @@ XLALInitUserVars ( UserVariables_t *uvar, int argc, char *argv[] )
   XLALregREALUserStruct (  SFTWindowBeta,        0, UVAR_OPTIONAL, "Window 'beta' parameter required for a few window-types (eg. 'tukey')");
 
   /* pulsar params */
-  XLALregLISTUserStruct( injectionSources,     0, UVAR_OPTIONAL, "Either a file-specification (\"@file-pattern\") or a config-string defining the sources to inject" );
+  XLALregLISTUserStruct( injectionSources,     0, UVAR_OPTIONAL,  "Source parameters to inject: comma-separated list of file-patterns and/or direct config-strings ('{...}')" );
 
   /* noise */
   XLALregSTRINGUserStruct ( noiseSFTs,          'D', UVAR_OPTIONAL, "Noise-SFTs to be added to signal (Used also to set IFOs and timestamps)");
@@ -517,7 +517,7 @@ XLALInitUserVars ( UserVariables_t *uvar, int argc, char *argv[] )
   XLALregBOOLUserStruct (  version,             'V', UVAR_SPECIAL, "Output version information");
 
   /* ----- 'expert-user/developer' options ----- */
-  XLALregINTUserStruct (   randSeed,             0, UVAR_DEVELOPER, "Specify random-number seed for reproducible noise (use /dev/urandom otherwise).");
+  XLALregINTUserStruct (   randSeed,             0, UVAR_DEVELOPER, "Specify random-number seed for reproducible noise (use system time otherwise).");
 
   /* read cmdline & cfgfile  */
   ret = XLALUserVarReadAllInput ( argc, argv );
