@@ -21,17 +21,15 @@
 #define __ANTENNA_H__
 
 #include <lal/AVFactories.h>
-#include <lal/DetResponse.h>
-#include <lal/Velocity.h>
 #include <lal/DetectorStates.h>
 
-INT4 CompBinShifts(INT4Vector *output, REAL8 freq, REAL4Vector *velocities, REAL8 Tcoh, REAL4 dopplerMultiplier);
+INT4 CompBinShifts(INT4Vector *output, REAL8 freq, REAL4Vector *velocities, REAL8 Tsft, REAL4 dopplerMultiplier);
 INT4 CompBinShifts2(INT4Vector *output, SSBtimes *ssbTimes, REAL8 freq, REAL8 Tsft, REAL4 dopplerMultiplier);
-INT4 CompAntennaPatternWeights(REAL4Vector *output, REAL4 ra, REAL4 dec, REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, INT4 linPolOn, REAL8 polAngle, LALDetector det);
-INT4 CompAntennaVelocity(REAL4Vector *output, REAL4 ra, REAL4 dec, REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat);
+INT4 CompAntennaPatternWeights(REAL4Vector *output, SkyPosition skypos, REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, BOOLEAN linPolOn, REAL8 polAngle, LALDetector det);
+INT4 CompAntennaVelocity(REAL4Vector *output, SkyPosition skypos, REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat);
 
-REAL4 CompDetectorDeltaVmax(REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat);
-REAL4 CompDetectorVmax(REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat);
+REAL4 CompDetectorDeltaVmax(REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat);
+REAL4 CompDetectorVmax(REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat);
 
 #endif
 
