@@ -22,7 +22,8 @@
 
 /**
  * \file
- * \brief Header file for DriveHoughFStat.c
+ * \ingroup lalapps_pulsar_hough
+ * \brief Header file for DriveHoughFstat.c
  * \author Badri Krishnan, Alicia Sintes
  *
  */
@@ -32,7 +33,6 @@
 #define _DRIVEHOUGHCOLOR_H
 
 /* standard includes */
-#include <unistd.h>
 #include <sys/types.h>
 #include <fcntl.h>
 #include <string.h>
@@ -53,7 +53,6 @@
 #include <lal/ComputeSky.h>
 #include <lal/LALInitBarycenter.h>
 #include <lal/Velocity.h>
-#include <lal/LALDemod.h>
 #include <lal/ExtrapolatePulsarSpins.h>
 #include <lal/Date.h>
 #include <lal/LALHough.h> 
@@ -68,7 +67,7 @@
 #include <lalapps.h>
 
 /* more efficient toplist using heaps */
-#include "HoughFStatToplist.h"
+#include "HoughFstatToplist.h"
 
 /******************************************************
  *   Protection against C++ name mangling
