@@ -21,6 +21,232 @@
  *
  */
 
+/**
+ * \file
+ * \ingroup lalapps_inspiral
+ *
+ *
+ * <dl>
+ * <dt>Name</dt><dd>
+ * <tt>lalapps_stochastic</tt> --- standalone stochastic analysis code.</dd>
+ *
+ * <dt>Synopsis</dt><dd>
+ * <tt>lalapps_stochastic</tt>
+ * [<tt>--help</tt>]
+ * [<tt>--version</tt>]
+ * [<tt>--verbose</tt>]
+ * [<tt>--debug</tt>]
+ * [<tt>--user-tag</tt> <i>STRING</i>]
+ * [<tt>--comment</tt> <i>STRING</i>]
+ * [<tt>--output-dir</tt> <i>DIR</i>]
+ * [<tt>--cc-spectra</tt>]
+ * <tt>--gps-start-time</tt> <i>N</i>
+ * <tt>--gps-end-time</tt> <i>N</i>
+ * <tt>--interval-duration</tt> <i>N</i>
+ * <tt>--segment-duration</tt> <i>N</i>
+ * <tt>--resample-rate</tt> <i>N</i>
+ * <tt>--f-min</tt> <i>N</i>
+ * <tt>--f-max</tt> <i>N</i>
+ * <tt>--ifo-one</tt> <i>IFO</i>
+ * <tt>--ifo-two</tt> <i>IFO</i>
+ * <tt>--channel-one</tt> <i>CHANNEL</i>
+ * <tt>--channel-two</tt> <i>CHANNEL</i>
+ * <tt>--frame-cache-one</tt> <i>FILE</i>
+ * <tt>--frame-cache-two</tt> <i>FILE</i>
+ * <tt>--calibration-cache-one</tt> <i>FILE</i>
+ * <tt>--calibration-cache-two</tt> <i>FILE</i>
+ * <tt>--calibration-offset</tt> <i>N</i>
+ * [<tt>--apply-mask</tt> <i>N</i>
+ * <tt>--mask-bin</tt> <i>N</i>]
+ * [<tt>--overlap-hann</tt>
+ * <tt>--hann-duration</tt> <i>N</i>]
+ * [<tt>--high-pass-filter</tt>
+ * <tt>--hpf-frequency</tt> <i>N</i>
+ * <tt>--hpf-attenuation</tt> <i>N</i>
+ * <tt>--hpf-order</tt> <i>N</i>]
+ * <tt>--recentre</tt>
+ * <tt>--middle-segment</tt>
+ * [<tt>--geo-hpf-frequency</tt> <i>N</i>
+ * <tt>--geo-hpf-attenuation</tt> <i>N</i>
+ * <tt>--geo-hpf-order</tt> <i>N</i>]
+ * [<tt>--alpha</tt> <i>N</i>]
+ * [<tt>--f-ref</tt> <i>N</i>]
+ * [<tt>--omega0</tt> <i>N</i>]</dd>
+ *
+ * <dt>Description</dt><dd>
+ * <tt>lalapps_stochastic</tt> runs the standalone stochastic analysis code.</dd>
+ *
+ * <dt>Options</dt><dd>
+ * <dl>
+ * <dt><tt>--help</tt></dt><dd>
+ * Display usage information and exit.</dd>
+ *
+ * <dt><tt>--version</tt></dt><dd>
+ * Display version information and exit.</dd>
+ *
+ * <dt><tt>--verbose</tt></dt><dd>
+ * Enable the output of informational messages.</dd>
+ *
+ * <dt><tt>--debug</tt></dt><dd>
+ * Run in debug mode, saves out all intermediate products as ASCII files.</dd>
+ *
+ * <dt><tt>--user-tag</tt> <i>STRING</i></dt><dd>
+ * Set the user tag to the string <i>STRING</i>. This string must not
+ * contain spaces or dashes ("-"). This string will appear in the name of
+ * the file to which output information is written, and is recorded in the
+ * various XML tables within the file.</dd>
+ *
+ * <dt><tt>--comment</tt> <i>STRING</i></dt><dd>
+ * Set the process table comment to <i>STRING</i></dd>
+ *
+ * <dt><tt>--output-dir</tt> <i>DIR</i></dt><dd>
+ * Set the output directory for search results to <i>DIR</i></dd>
+ *
+ * <dt><tt>--cc-spectra</tt></dt><dd>
+ * Save out cross correlation spectra as frame files.</dd>
+ *
+ * <dt><tt>--gps-start-time</tt> <i>N</i></dt><dd>
+ * Sets the GPS time from which data should be read to <i>N</i></dd>
+ *
+ * <dt><tt>--gps-end-time</tt> <i>N</i></dt><dd>
+ * Sets the GPS time to which data should be read to <i>N</i></dd>
+ *
+ * <dt><tt>--interval-duration</tt> <i>N</i></dt><dd>
+ * Sets the interval duration to <i>N</i></dd>
+ *
+ * <dt><tt>--segment-duration</tt> <i>N</i></dt><dd>
+ * Sets the segment duration to <i>N</i></dd>
+ *
+ * <dt><tt>--resample-rate</tt> <i>N</i></dt><dd>
+ * Down-convert the input data stream to a sample rate of <i>N</i> samples
+ * per second prior to analysis.  This can be used to reduce the number of CPU
+ * cycles required to analyze a given quantity of input data.</dd>
+ *
+ * <dt><tt>--f-min</tt> <i>N</i></dt><dd>
+ * Sets the minimum frequency of the search band to <i>N</i></dd>
+ *
+ * <dt><tt>--f-max</tt> <i>N</i></dt><dd>
+ * Sets the maximum frequency of the search band to <i>N</i></dd>
+ *
+ * <dt><tt>--ifo-one</tt> <i>IFO</i></dt><dd>
+ * Sets the IFO for the first stream to be <i>IFO</i>, currently supported
+ * IFO's are H1, H2, L1 and G1</dd>
+ *
+ * <dt><tt>--ifo-two</tt> <i>IFO</i></dt><dd>
+ * Sets the IFO for the second stream to be <i>IFO</i>, currently supported
+ * IFO's are H1, H2, L1 and G1</dd>
+ *
+ * <dt><tt>--channel-one</tt> <i>CHANNEL</i></dt><dd>
+ * Sets the channel for the first stream to be <i>CHANNEL</i></dd>
+ *
+ * <dt><tt>--channel-two</tt> <i>CHANNEL</i></dt><dd>
+ * Sets the channel for the second stream to be <i>CHANNEL</i></dd>
+ *
+ * <dt><tt>--frame-cache-one</tt> <i>FILE</i></dt><dd>
+ * Obtain the locations of input <tt>.gwf</tt> frame files from the LAL frame
+ * cache file <i>FILE</i> for the first detector.  LAL frame cache files
+ * are explained in the "framedata" package in LAL and can be constructed
+ * by using <tt>LSCdataFind</tt> on supported systems.</dd>
+ *
+ * <dt><tt>--frame-cache-two</tt> <i>FILE</i></dt><dd>
+ * Obtain the locations of input <tt>.gwf</tt> frame files from the LAL frame
+ * cache file <i>FILE</i> for the second detector.  LAL frame cache files
+ * are explained in the "framedata" package in LAL and can be constructed
+ * by using <tt>LSCdataFind</tt> on supported systems.</dd>
+ *
+ * <dt><tt>--calibration-cache-one</tt> <i>FILE</i></dt><dd>
+ * Specify the location of calibration information for the first detector.
+ * <i>FILE</i> gives the path to a LAL-format frame cache file describing
+ * locations of <tt>.gwf</tt> frame files that provide the calibration data
+ * (\f$\alpha\f$ and \f$\beta\f$ coefficients) for the analysis.  Frame cache files
+ * are explained in the "framedata" package in LAL.</dd>
+ *
+ * <dt><tt>--calibration-cache-two</tt> <i>FILE</i></dt><dd>
+ * Specify the location of calibration information for the second detector.
+ * <i>FILE</i> gives the path to a LAL-format frame cache file describing
+ * locations of <tt>.gwf</tt> frame files that provide the calibration data
+ * (\f$\alpha\f$ and \f$\beta\f$ coefficients) for the analysis.  Frame cache files
+ * are explained in the "framedata" package in LAL.</dd>
+ *
+ * <dt><tt>--calibration-offset</tt> <i>N</i></dt><dd>
+ * Sets the calibration offset to <i>N</i></dd>
+ *
+ * <dt><tt>--apply-mask</tt></dt><dd>
+ * Apply frequency masking</dd>
+ *
+ * <dt><tt>--mask-bin</tt> <i>N</i></dt><dd>
+ * Set the number of bins to mask per frequency to <i>N</i></dd>
+ *
+ * <dt><tt>--overlap-hann</tt></dt><dd>
+ * Use overlapping Hann windows for data segments</dd>
+ *
+ * <dt><tt>--hann-duration</tt> <i>N</i></dt><dd>
+ * Set the Hann duration of the data segment window to <i>N</i>, 0 for
+ * Rectangular windowing, 1 for Tukey windowing and 60 for Hann windowing</dd>
+ *
+ * <dt><tt>--high-pass-filter</tt></dt><dd>
+ * Apply a high pass filter to the input data</dd>
+ *
+ * <dt><tt>--hpf-frequency</tt> <i>N</i></dt><dd>
+ * Set the knee frequency of the high pass filter to <i>N</i></dd>
+ *
+ * <dt><tt>--hpf-attenuation</tt> <i>N</i></dt><dd>
+ * Set the attenuation coefficent for the high pass filter to <i>N</i></dd>
+ *
+ * <dt><tt>--hpf-order</tt> <i>N</i></dt><dd>
+ * Sets the high pass filter order to <i>N</i></dd>
+ *
+ * <dt><tt>--recentre</tt></dt><dd>
+ * Centre the data</dd>
+ *
+ * <dt><tt>--middle-segment</tt></dt><dd>
+ * Include the middle segment in the power spectra estimation</dd>
+ *
+ * <dt><tt>--geo-hpf-frequency</tt> <i>N</i></dt><dd>
+ * Set the knee frequency for the GEO high pass filter to <i>N</i></dd>
+ *
+ * <dt><tt>--geo-hpf-attenuation</tt> <i>N</i></dt><dd>
+ * Set the attenuation coefficient for the GEO high pass filter to <i>N</i></dd>
+ *
+ * <dt><tt>--geo-hpf-order</tt> <i>N</i></dt><dd>
+ * Set the GEO high pass filter order to <i>N</i></dd>
+ *
+ * <dt><tt>--alpha</tt> <i>N</i></dt><dd>
+ * Exponent for \f$\Omega_{\mathrm{GW}}\f$ for construction of the optimal
+ * filter.</dd>
+ *
+ * <dt><tt>--f-ref</tt> <i>N</i></dt><dd>
+ * Reference frequency for \f$\Omega_{\mathrm{GW}}\f$ for the construction of
+ * the optimal filter.</dd>
+ *
+ * <dt><tt>--omega0</tt> <i>N</i></dt><dd>
+ * Reference \f$\Omega_0\f$ for \f$\Omega_{\mathrm{GW}}\f$ for the construction of
+ * the optimal filter.</dd>
+ * </dl></dd>
+ *
+ * <dt>Example</dt><dd>
+ * <tt>lalapps_stochastic</tt> is generally run as part of a DAG, as created
+ * by the pipeline generation scripts, <tt>lalapps_stochastic_pipe</tt> or
+ * <tt>lalapps_stochastic_bayes</tt>, however an example usage can be seen
+ * below.
+ *
+ * \code
+ * > lalapps_stochastic --verbose \
+ * >   --gps-start-time 752242398 --gps-end-time 752242758 \
+ * >   --interval-duration 180 --segment-duration 60 \
+ * >   --resample-rate 1024 --f-min 50 --f-max 250 --ifo-one H1 \
+ * >   --ifo-two H2 --channel-one LSC-AS_Q --channel-two LSC-AS_Q \
+ * >   --frame-cache-one H1.cache --frame-cache-two H2.cache \
+ * >   --calibration-cache-one H1-CAL-V02-751651244-757699245.cache \
+ * >   --calibration-cache-two H2-CAL-V02-751651244-757699245.cache \
+ * >   --calibration-offset 0 --hann-duration 1 --cc-spectra
+ * \endcode</dd>
+ *
+ * <dt>Author</dt><dd>
+ * Adam Mercer, Tania Regimbau</dd>
+ * </dl>
+ */
+
 #include "data_input.h"
 #include "misc.h"
 #include "sgwb.h"
@@ -31,7 +257,7 @@
 /* program info */
 const CHAR* prog_name="lalapps_stochastic";
 
-/* flags for getopt_long */
+/* flags for LALgetopt_long */
 int middle_segment_flag;
 int apply_mask_flag;
 int high_pass_flag;
@@ -163,7 +389,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
   while(1)
   {
-    static struct option long_options[] =
+    static struct LALoption long_options[] =
     {
       /* options that set a flag */
       {"middle-segment", no_argument, &middle_segment_flag, 1},
@@ -210,11 +436,11 @@ static void parse_options(INT4 argc, CHAR *argv[])
       {0, 0, 0, 0}
     };
 
-    /* getopt_long stores the option here */
+    /* LALgetopt_long stores the option here */
     int option_index = 0;
-    size_t optarg_len;
+    size_t LALoptarg_len;
 
-    c = getopt_long_only(argc, argv, \
+    c = LALgetopt_long_only(argc, argv, \
         "abd:e:f:g:h:i:j:k:l:m:n:o:p:q:r:s:t:u:v:w:x:y:z:" \
         "A:B:C:D:E:F:G:", long_options, &option_index);
 
@@ -235,7 +461,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
         else
         {
           fprintf(stderr, "error parseing option %s with argument %s\n", \
-              long_options[option_index].name, optarg);
+              long_options[option_index].name, LALoptarg);
           exit(1);
         }
         break;
@@ -255,9 +481,9 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'd':
         /* user tag */
-        optarg_len = strlen(optarg) + 1;
-        userTag = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(userTag, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        userTag = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(userTag, LALoptarg, LALoptarg_len);
 
         /* add to process_params table */
         this_proc_param = this_proc_param->next = (ProcessParamsTable *) \
@@ -265,12 +491,12 @@ static void parse_options(INT4 argc, CHAR *argv[])
         snprintf(this_proc_param->program, LIGOMETA_PROGRAM_MAX, "%s", prog_name);
         snprintf(this_proc_param->param, LIGOMETA_PARAM_MAX, "--user-tag");
         snprintf(this_proc_param->type, LIGOMETA_TYPE_MAX, "string");
-        snprintf(this_proc_param->value, LIGOMETA_VALUE_MAX, "%s", optarg);
+        snprintf(this_proc_param->value, LIGOMETA_VALUE_MAX, "%s", LALoptarg);
         break;
 
       case 'e':
         /* xml comment */
-        if (strlen(optarg) > LIGOMETA_COMMENT_MAX - 1)
+        if (strlen(LALoptarg) > LIGOMETA_COMMENT_MAX - 1)
         {
           fprintf(stderr, "invalid argument to --%s:\n" \
               "comment must be less than %d characters\n", \
@@ -279,15 +505,15 @@ static void parse_options(INT4 argc, CHAR *argv[])
         }
         else
         {
-          snprintf(comment, LIGOMETA_COMMENT_MAX, "%s", optarg);
+          snprintf(comment, LIGOMETA_COMMENT_MAX, "%s", LALoptarg);
         }
         break;
 
       case 'f':
         /* directory for output files */
-        optarg_len = strlen(optarg) + 1;
-        outputPath = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(outputPath, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        outputPath = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(outputPath, LALoptarg, LALoptarg_len);
         if (stat(outputPath, &fileStatus) == -1)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -300,7 +526,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'g':
         /* start time */
-        startTime = atoi(optarg);
+        startTime = atoi(LALoptarg);
         if (startTime < 441217609)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -322,7 +548,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'h':
         /* end time */
-        endTime = atoi(optarg);
+        endTime = atoi(LALoptarg);
         if (endTime < 441217609)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -344,7 +570,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'i':
         /* interval duration */
-        intervalDuration = atoi(optarg);
+        intervalDuration = atoi(LALoptarg);
         if (intervalDuration <= 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -357,7 +583,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'j':
         /* segment duration */
-        segmentDuration = atoi(optarg);
+        segmentDuration = atoi(LALoptarg);
         if (segmentDuration <= 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -370,7 +596,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'k':
         /* resample rate */
-        resampleRate = atoi(optarg);
+        resampleRate = atoi(LALoptarg);
         if (resampleRate < 2 || resampleRate > 16384 || resampleRate % 2)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -385,7 +611,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'l':
         /* minimal frequency */
-        fMin = atof(optarg);
+        fMin = atof(LALoptarg);
         if (fMin < 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -405,7 +631,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'm':
         /* maximal frequency */
-        fMax = atof(optarg);
+        fMax = atof(LALoptarg);
         if (fMax < 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -425,9 +651,9 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'n':
         /* ifo for first stream */
-        optarg_len = strlen(optarg) + 1;
-        ifoOne = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(ifoOne, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        ifoOne = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(ifoOne, LALoptarg, LALoptarg_len);
 
         /* set site id for ifo one */
         if (strncmp(ifoOne, "H1", 2) == 0)
@@ -448,9 +674,9 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'o':
         /* ifo for second stream */
-        optarg_len = strlen(optarg) + 1;
-        ifoTwo = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(ifoTwo, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        ifoTwo = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(ifoTwo, LALoptarg, LALoptarg_len);
 
         /* set site id for ifo two */
         if (strncmp(ifoTwo, "H1", 2) == 0)
@@ -471,27 +697,27 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'p':
         /* channel one */
-        optarg_len = strlen(optarg) + 4;
-        channelOneTemp = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        channelOne = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(channelOneTemp, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 4;
+        channelOneTemp = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        channelOne = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(channelOneTemp, LALoptarg, LALoptarg_len);
         ADD_PROCESS_PARAM("string", "%s", channelOneTemp);
         break;
 
       case 'q':
         /* channel two */
-        optarg_len = strlen(optarg) + 4;
-        channelTwoTemp = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        channelTwo = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(channelTwoTemp, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 4;
+        channelTwoTemp = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        channelTwo = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(channelTwoTemp, LALoptarg, LALoptarg_len);
         ADD_PROCESS_PARAM("string", "%s", channelTwoTemp);
         break;
 
       case 'r':
         /* frame cache one */
-        optarg_len = strlen(optarg) + 1;
-        frameCacheOne = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(frameCacheOne, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        frameCacheOne = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(frameCacheOne, LALoptarg, LALoptarg_len);
         if (stat(frameCacheOne, &fileStatus) == -1)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -504,9 +730,9 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 's':
         /* frame cache two */
-        optarg_len = strlen(optarg) + 1;
-        frameCacheTwo = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(frameCacheTwo, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        frameCacheTwo = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(frameCacheTwo, LALoptarg, LALoptarg_len);
         if (stat(frameCacheTwo, &fileStatus) == -1)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -519,9 +745,9 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 't':
         /* calibration cache one */
-        optarg_len = strlen(optarg) + 1;
-        calCacheOne = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(calCacheOne, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        calCacheOne = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(calCacheOne, LALoptarg, LALoptarg_len);
         if (stat(calCacheOne, &fileStatus) == -1)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -534,9 +760,9 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'u':
         /* calibration cache two */
-        optarg_len = strlen(optarg) + 1;
-        calCacheTwo = (CHAR*)calloc(optarg_len, sizeof(CHAR));
-        memcpy(calCacheTwo, optarg, optarg_len);
+        LALoptarg_len = strlen(LALoptarg) + 1;
+        calCacheTwo = (CHAR*)calloc(LALoptarg_len, sizeof(CHAR));
+        memcpy(calCacheTwo, LALoptarg, LALoptarg_len);
         if (stat(calCacheTwo, &fileStatus) == -1)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -549,13 +775,13 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'v':
         /* calibration time offset */
-        calibOffset = atoi(optarg);
+        calibOffset = atoi(LALoptarg);
         ADD_PROCESS_PARAM("int", "%d", calibOffset);
         break;
 
       case 'w':
         /* number of bins to mask for frequency mask */
-        maskBin = atoi(optarg);
+        maskBin = atoi(LALoptarg);
         if (maskBin <= 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -568,7 +794,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'x':
         /* hann window duration */
-        hannDuration = atoi(optarg);
+        hannDuration = atoi(LALoptarg);
         if (hannDuration < 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -581,7 +807,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'y':
         /* high pass knee filter frequency  */
-        highPassFreq = atof(optarg);
+        highPassFreq = atof(LALoptarg);
         if (highPassFreq < 0)
         {
           fprintf(stderr, "Invalid argument tp --%s:\n" \
@@ -595,7 +821,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'z':
         /* high pass filter attenuation  */
-        highPassAtten = atof(optarg);
+        highPassAtten = atof(LALoptarg);
         if ((highPassAtten < 0.0) || (highPassAtten > 1.0))
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -609,7 +835,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'A':
         /* high pass filter order  */
-        highPassOrder = atoi(optarg);
+        highPassOrder = atoi(LALoptarg);
         if (highPassOrder <= 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -623,7 +849,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'B':
         /* GEO high pass knee filter frequency */
-        geoHighPassFreq = atof(optarg);
+        geoHighPassFreq = atof(LALoptarg);
         if (geoHighPassFreq < 0)
         {
           fprintf(stderr, "Invalid argument tp --%s:\n" \
@@ -637,7 +863,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'C':
         /* GEO high pass filter attenuation */
-        geoHighPassAtten = atof(optarg);
+        geoHighPassAtten = atof(LALoptarg);
         if ((geoHighPassAtten < 0.0) || (geoHighPassAtten > 1.0))
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -651,7 +877,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'D':
         /* GEO high pass filter order */
-        geoHighPassOrder = atoi(optarg);
+        geoHighPassOrder = atoi(LALoptarg);
         if (geoHighPassOrder <= 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -665,13 +891,13 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'E':
         /* filter spectrum exponent */
-        alpha = atof(optarg);
+        alpha = atof(LALoptarg);
         ADD_PROCESS_PARAM("float", "%e", alpha);
         break;
 
       case 'F':
         /* filter reference frequency */
-        fRef = atof(optarg);
+        fRef = atof(LALoptarg);
         if (fRef < 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -684,7 +910,7 @@ static void parse_options(INT4 argc, CHAR *argv[])
 
       case 'G':
         /* filter reference omega */
-        omegaRef = atof(optarg);
+        omegaRef = atof(LALoptarg);
         if (omegaRef <= 0)
         {
           fprintf(stderr, "Invalid argument to --%s:\n" \
@@ -705,12 +931,12 @@ static void parse_options(INT4 argc, CHAR *argv[])
     }
   }
 
-  if (optind < argc)
+  if (LALoptind < argc)
   {
     fprintf(stderr, "Extraneous command line arguments:\n");
-    while(optind < argc)
+    while(LALoptind < argc)
     {
-      fprintf(stderr, "%s\n", argv[optind++]);
+      fprintf(stderr, "%s\n", argv[LALoptind++]);
     }
     exit(1);
   }
